""" xbox compatibilty module """

__all__ = [ "XBMCADDON" ]

import os
import xbmc
import re

# get current working directory
cwd = os.getcwd()
# check if we're at root folder of addon
if ( not os.path.isfile( os.path.join( cwd, "addon.xml" ) ) ):
    # we're not at root, assume resources/lib/
    cwd = os.path.dirname( os.path.dirname( os.getcwd() ) )

# language module
_language_ = xbmc.Language( cwd ).getLocalizedString
# settings module, try catch necessary as not all scripts have settings
try:
    _settings_ = xbmc.Settings( cwd )
except:
    _settings_ = None


class XBMCADDON:
    """
        xbmcaddon module class
    """
    # dictionary to hold addon info
    INFO = {}

    class Addon:
        """
            Class to emulate xbmcaddon.Addon methods.
        """
        def __init__( self, id ):
            # TODO: do we want to use id for anything?
            # parse addon.xml and set all addon info
            self._set_addon_info( id )

        def _set_addon_info( self, id ):
            # get source
            xml = open( os.path.join( cwd, "addon.xml" ), "r" ).read()
            # set addon.xml info into dictionary
            XBMCADDON.INFO[ "id" ], XBMCADDON.INFO[ "name" ], XBMCADDON.INFO[ "version" ], XBMCADDON.INFO[ "author" ] = re.search( "<addon id=\"([^\"]+)\".+?name=\"([^\"]+)\".+?version=\"([^\"]+)\".+?provider-name=\"([^\"]+)\".*?>", xml, re.DOTALL ).groups( 1 )
            XBMCADDON.INFO[ "type" ], XBMCADDON.INFO[ "library" ] = re.search(  "<extension point=\"([^\"]+)\".+?library=\"([^\"]+)\".*?>", xml, re.DOTALL ).groups( 1 )
            # reset this to default.py as that's what xbox uses
            XBMCADDON.INFO[ "library" ] = "default.py"
            for metadata in [ "summary", "disclaimer", "description" ]:
                XBMCADDON.INFO[ metadata ] = re.search( "(?:<%s>([^<]*)</%s>)?" % ( metadata, metadata, ), xml, re.DOTALL ).group( 1 )
            # set other info
            XBMCADDON.INFO[ "path" ] = cwd
            XBMCADDON.INFO[ "libpath" ] = os.path.join( cwd, XBMCADDON.INFO[ "library" ] )
            XBMCADDON.INFO[ "icon" ] = os.path.join( cwd, "default.tbn" )
            XBMCADDON.INFO[ "fanart" ] = os.path.join( cwd, "fanart.jpg" )
            XBMCADDON.INFO[ "changelog" ] = os.path.join( cwd, "changelog.txt" )
            if ( cwd.startswith( "Q:\\plugins" ) and not cwd.startswith( "Q:\\plugins\\weather" ) ):
                XBMCADDON.INFO[ "profile" ] = "special://profile/plugin_data/%s/%s" % ( os.path.basename( os.path.dirname( cwd ) ), os.path.basename( cwd ), )
            else:
                XBMCADDON.INFO[ "profile" ] = "special://profile/script_data/%s" % ( os.path.basename( cwd ), )

        @staticmethod
        def getLocalizedString( id ):
            return _language_( id )

        @staticmethod
        def getSetting( id ):
            return _settings_.getSetting( id )

        @staticmethod
        def setSetting( id, value ):
            _settings_.setSetting( id, value )

        @staticmethod
        def openSettings():
            _settings_.openSettings()

        @staticmethod
        def getAddonInfo( id ):
            return XBMCADDON.INFO[ id.lower() ]
